@@ -4,14 +4,16 @@
     sijax.plugin.comet
     ~~~~~~~~~~~~~~~~~~
 
-    Provides helpers to register Comet functions.
+    Provides helpers to register Comet functions,
+    and the :class:`sijax.plugin.comet.CometResponse` class
+    used instead of :class:`sijax.response.BaseResponse`.
 
     :copyright: (c) 2011 by Slavi Pantaleev.
     :license: BSD, see LICENSE.txt for more details.
 """
 
 
-from .CometResponse import CometResponse
+from ...response import StreamingIframeResponse
 
 
 def _prepare_options(sijax_instance, options):
@@ -26,7 +28,7 @@ def register_comet_callback(sijax_instance, public_name, callback, **options):
     """Helps you easily register Comet functions with Sijax.
 
     This is the analogue of
-    :meth:`sijax.Sijax.Sijax.register_callback`,
+    :meth:`sijax.Sijax.register_callback`,
     but makes the registered function support Comet functionality.
 
     Comet functions need to be called from the browser using::
@@ -37,10 +39,10 @@ def register_comet_callback(sijax_instance, public_name, callback, **options):
 
         Sijax.request('function_name');
     
-    :param sijax_instance: the :class:`sijax.Sijax.Sijax` instance to register callbacks with
+    :param sijax_instance: the :class:`sijax.Sijax` instance to register callbacks with
     :param public_name: the name of the function that the client will use to call it
     :param callback: the actual function that would get called to process the request
-    :param options: options to pass to :meth:`sijax.Sijax.Sijax.register_callback`
+    :param options: options to pass to :meth:`sijax.Sijax.register_callback`
     """
     options = _prepare_options(sijax_instance, options)
     sijax_instance.register_callback(public_name, callback, **options)
@@ -50,13 +52,22 @@ def register_comet_object(sijax_instance, obj, **options):
     """Helps you easily register all "public" callable attributes of an object.
 
     This is the analogue of
-    :meth:`sijax.Sijax.Sijax.register_object`,
+    :meth:`sijax.Sijax.register_object`,
     but makes the registered functions support Comet functionality.
 
-    :param sijax_instance: the :class:`sijax.Sijax.Sijax` instance to register callbacks with
+    :param sijax_instance: the :class:`sijax.Sijax` instance to register callbacks with
     :param obj: the object whose methods to register with Sijax
-    :param options: options to pass to :meth:`sijax.Sijax.Sijax.register_callback`
+    :param options: options to pass to :meth:`sijax.Sijax.register_callback`
     """
     options = _prepare_options(sijax_instance, options)
     sijax_instance.register_object(obj, **options)
         
+
+class CometResponse(StreamingIframeResponse):
+    """Class used for Comet handler functions,
+    instead of the :class:`sijax.response.BaseResponse` class.
+
+    This class extends :class:`sijax.response.BaseResponse` and
+    every available method from it works here too.
+    """
+    pass
